Index: trunk/MagicSoft/Mars/mhvstime/MHVsTime.h
===================================================================
--- trunk/MagicSoft/Mars/mhvstime/MHVsTime.h	(revision 8022)
+++ trunk/MagicSoft/Mars/mhvstime/MHVsTime.h	(revision 8082)
@@ -11,5 +11,5 @@
 
 class TGraph;
-class MDataChain;
+class MData;
 
 class MHVsTime : public MH
@@ -22,6 +22,6 @@
     // Could be const but root < 3.02/06 doesn't like this...
     TGraph     *fGraph;     // Histogram to fill
-    MDataChain *fData;      // Object from which the data is filled
-    MDataChain *fError;     // Object from which the error is filled
+    MData      *fData;      // Object from which the data is filled
+    MData      *fError;     // Object from which the error is filled
     Double_t    fScale;     // Scale for axis (eg unit)
     Int_t       fMaxPts;    // Maximum number of data points
@@ -78,5 +78,5 @@
     void SetMaxPts(Int_t n) { fMaxPts=n; }
 
-    ClassDef(MHVsTime, 1) // Generalized 1/2/3D-histogram for Mars variables
+    ClassDef(MHVsTime, 2) // Generalized 1/2/3D-histogram for Mars variables
 };
 

Index: trunk/MagicSoft/Mars/mhvstime/MHVsTime.cc
===================================================================
--- trunk/MagicSoft/Mars/mhvstime/MHVsTime.cc	(revision 8022)
+++ trunk/MagicSoft/Mars/mhvstime/MHVsTime.cc	(revision 8082)
@@ -50,4 +50,12 @@
 // SetMaxPts(-1) disables this feature.
 //
+//
+// Class Version 2:
+// ----------------
+//  + MData      *fData;      // Object from which the data is filled
+//  - MDataChain *fData;      // Object from which the data is filled
+//  + MData      *fError;     // Object from which the error is filled
+//  - MDataChain *fError;     // Object from which the error is filled
+//
 /////////////////////////////////////////////////////////////////////////////
 #include "MHVsTime.h"
@@ -67,5 +75,5 @@
 #include "MTime.h"
 #include "MParList.h"
-#include "MDataChain.h"
+#include "MDataPhrase.h"
 #include "MRawEvtHeader.h"
 
@@ -80,5 +88,5 @@
 //
 // Default constructor. For more informations about a valid rule
-// see MDataChain.
+// see MDataPhrase.
 //
 MHVsTime::MHVsTime(const char *rule, const char *error)
@@ -92,8 +100,8 @@
         return;
 
-    fData = new MDataChain(rule);
+    fData = new MDataPhrase(rule);
 
     if (error)
-        fError = new MDataChain(error);
+        fError = new MDataPhrase(error);
 
     fGraph = error ? new TGraphErrors : new TGraph;
@@ -141,5 +149,5 @@
 // --------------------------------------------------------------------------
 //
 // PreProcess the MDataChain. Create a new TGraph. Delete an old one if
 // already allocated.
 //
@@ -141,5 +149,5 @@
 // --------------------------------------------------------------------------
 //
-// PreProcess the MDataChain. Create a new TGraph. Delete an old one if
+// PreProcess the MDataPhrase. Create a new TGraph. Delete an old one if
 // already allocated.
 //